==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/EMPLOYEEAVAILABILITYEXCEPTION_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.TIME;


/**
 * <p>Classe Java pour EMPLOYEEAVAILABILITYEXCEPTION_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EMPLOYEEAVAILABILITYEXCEPTION_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEECODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEEAVAILABILITYDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEEAVAILABILITYSTARTTIME"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EMPLOYEEAVAILABILITYEXCEPTION_Type", propOrder = {
    "employeecode",
    "employeeavailabilitydate",
    "employeeavailabilitystarttime"
})
public class EMPLOYEEAVAILABILITYEXCEPTION_Type {

    @XmlElement(name = "EMPLOYEECODE", required = true)
    protected String employeecode;
    @XmlElement(name = "EMPLOYEEAVAILABILITYDATE", required = true)
    protected DATETIME employeeavailabilitydate;
    @XmlElement(name = "EMPLOYEEAVAILABILITYSTARTTIME", required = true)
    protected TIME employeeavailabilitystarttime;

    /**
     * Obtient la valeur de la propriété employeecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMPLOYEECODE() {
        return employeecode;
    }

    /**
     * Définit la valeur de la propriété employeecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMPLOYEECODE(String value) {
        this.employeecode = value;
    }

    /**
     * Obtient la valeur de la propriété employeeavailabilitydate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getEMPLOYEEAVAILABILITYDATE() {
        return employeeavailabilitydate;
    }

    /**
     * Définit la valeur de la propriété employeeavailabilitydate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setEMPLOYEEAVAILABILITYDATE(DATETIME value) {
        this.employeeavailabilitydate = value;
    }

    /**
     * Obtient la valeur de la propriété employeeavailabilitystarttime.
     * 
     * @return
     *     possible object is
     *     {@link TIME }
     *     
     */
    public TIME getEMPLOYEEAVAILABILITYSTARTTIME() {
        return employeeavailabilitystarttime;
    }

    /**
     * Définit la valeur de la propriété employeeavailabilitystarttime.
     * 
     * @param value
     *     allowed object is
     *     {@link TIME }
     *     
     */
    public void setEMPLOYEEAVAILABILITYSTARTTIME(TIME value) {
        this.employeeavailabilitystarttime = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/EMPLOYEEAVAILABILITYEXCEPTION_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.TIME;


/**
 * <p>Java class for EMPLOYEEAVAILABILITYEXCEPTION_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EMPLOYEEAVAILABILITYEXCEPTION_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEECODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEEAVAILABILITYDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEEAVAILABILITYSTARTTIME"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EMPLOYEEAVAILABILITYEXCEPTION_Type", propOrder = {
    "employeecode",
    "employeeavailabilitydate",
    "employeeavailabilitystarttime"
})
public class EMPLOYEEAVAILABILITYEXCEPTION_Type {

    @XmlElement(name = "EMPLOYEECODE", required = true)
    protected String employeecode;
    @XmlElement(name = "EMPLOYEEAVAILABILITYDATE", required = true)
    protected DATETIME employeeavailabilitydate;
    @XmlElement(name = "EMPLOYEEAVAILABILITYSTARTTIME", required = true)
    protected TIME employeeavailabilitystarttime;

    /**
     * Gets the value of the employeecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMPLOYEECODE() {
        return employeecode;
    }

    /**
     * Sets the value of the employeecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMPLOYEECODE(String value) {
        this.employeecode = value;
    }

    /**
     * Gets the value of the employeeavailabilitydate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getEMPLOYEEAVAILABILITYDATE() {
        return employeeavailabilitydate;
    }

    /**
     * Sets the value of the employeeavailabilitydate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setEMPLOYEEAVAILABILITYDATE(DATETIME value) {
        this.employeeavailabilitydate = value;
    }

    /**
     * Gets the value of the employeeavailabilitystarttime property.
     * 
     * @return
     *     possible object is
     *     {@link TIME }
     *     
     */
    public TIME getEMPLOYEEAVAILABILITYSTARTTIME() {
        return employeeavailabilitystarttime;
    }

    /**
     * Sets the value of the employeeavailabilitystarttime property.
     * 
     * @param value
     *     allowed object is
     *     {@link TIME }
     *     
     */
    public void setEMPLOYEEAVAILABILITYSTARTTIME(TIME value) {
        this.employeeavailabilitystarttime = value;
    }

}
